function trace_files, t0 ,t1, weeks=weeks, week_dirs=week_dirs, $
		      prefix=prefix, count=count, quiet=quiet, $
		      _extra=_extra, wave_length=wave_length, $
		      quicklook=quicklook, delta=delta, $
		      synop=synop, stra=stra
;+
;   Name: trace_files
;
;   Purpose: return trace reformatted file names between t0 and t1
;
;   Input Parameters:
;      t0 , t1 - start and stop times 
;
;   Calling Sequence:
;      filelist=trace_files(t0, t1 [,weeks=weeks, prefix='txx'] )
;
;   Keyword Parameters:
;      weeks  - asscociated weekly directories
;      prefix - prefix to check (default = 'tri')
;               (others /tma, /tmr, /synop, /stra)
;       
;   Calling Examples:
;      reffiles   =trace_files('1-jun','2-jun 12:30')
;      mosaicfiles=trace_files('2-jul-1998','7-jul-1998',prefix='tmr')
;      synop=trace_files('15-aug',wave=195,/synop)   ; assembled 1024x1024
;  
;   History:
;      26-March-1998 - S.L.Freeland - (based on eit_files, cds_files, etc)
;      16-April-1998 - S.L.Freeland - optimized time selection
;       8-July-1998  - S.L.Freeland - add PREFIX keyword and function
;      13-July-1998  - S.L.Freeland - allow PREFIX via keyword inherit
;      22-July-1998  - S.L.Freeland - add WAVE_LENGTH and /QUICKLOOK
;      23-July-1998  - S.L.Freeland - if only one time, get closest
;      28-Aug-1998   - S.L.Freeland - allow comma list for TRACE_I1_DIR
;       5-Oct-1998   - S.L.Freeland - add SYNOP/STRA  switches
;      29-Jan-1999   - S.L.Freeland - look for $SYNOP_DATA/trace if
;                                     $tdb/mosaics/fits not found
;                                     Merge another offline change
;       1-mar-1999   - S.L.Freeland - correct minor flaw in backup logic
;       8-mar-1999   - S.L.Freeland - fixed bug introduced 1-march
;      13-Jul-2000   - R.D.Bentley  - corrected format of message about week dirs.
;  
;   Restrictions:
;      parent directory $TRACE_I1_DIR must be defined ('tri' parent)
;      (and '$tdb' OR $SYNOP_DATA/trace for SYNOP/STR)
;-  
quicklook=keyword_set(quicklook)

case 1 of
  data_chk(prefix,/string,/scalar):
  keyword_set(synop) or keyword_set(stra): prefix='stra'    ; soho/synoptic
  data_chk(_extra,/struct): prefix=(tag_names(_extra))(0)
  else: prefix='tri'
endcase
lprefix=strlowcase(prefix)

topenv='TRACE_I1_DIR'
toptrace=str2arr(get_logenv(topenv))
toptrace=str_replace(toptrace,'tri',lprefix)

if prefix eq 'stra' then begin
   synops=[concat_dir(concat_dir('$tdb','mosaics'),'fits'),concat_dir('$SYNOP_DATA','trace')]
   synss=where(file_exist(synops),syncnt)
   if syncnt eq 0 then begin
      box_message,['No SYNOPTIC/MOSAIC dbase in: ','   ' +synops,'Returning...']
      return,''     
   endif
   toptrace=synops(synss(syncnt-1))          ; take las
endif

if quicklook then begin
   toptrace=get_logenv('trace_quicklook')
   if toptrace(0) eq '' then toptrace='/temp/quicklook'   
endif  

loud=1-keyword_set(quiet)

if not file_exist(toptrace(0)) then begin 
   box_message,'Need to define '+topenv +' (parent of weekly subdirectories)'
   return,''
endif

;; if times passed, form weekly subdirectorie
case 1 of 
   prefix(0) eq 'stra': weeks=toptrace
   n_params() eq 0:  weeks=file_list(toptrace,'week*')
   else: begin
      if n_elements(t1) eq 0 then t1=timegrid(t0,day=[-7,7],/string)
      grid=timegrid(timegrid(t0,hour=-1,/string),t1,/day,/quiet)
      weeks='week'+anytim2weekinfo(grid,/first)
      weeks=concat_dir(toptrace,weeks(uniq(weeks)))
    endelse
endcase

wavelen=''

if keyword_set(wave_length) then $
    wavelen=strupcase(strtrim(wave_length,2))+'_' + (['','fd'])(prefix eq 'stra')
box_message,reform(str_perm(weeks,'/'+lprefix+'*'+wavelen+'*'))

retval=file_list(weeks,lprefix+'*'+wavelen+'*',/cd)
delim=(['.','_'])(lprefix ne 'tri')

case n_params() of
   1: begin
;       box_message,'Only one time - getting closest in time'
        ss=tim2dset(file2time(retval,out='ints'), t0, delta=delta)
        if delta(0) gt 0 and prefix eq 'tri' then ss=(ss-1)>0 ; back up
        retval=retval(ss)
      endcase

   2: begin
      fids=extract_fid(retval)
      fid0=time2file(anytim(t0,/int),delim=delim)      
      if prefix eq 'tri' then fid0=(strmids(fid0,0,strlen(fid0)-2)+'00')(0) ; round
      fid1=time2file(t1,delim=delim)
      ss=where(fids ge fid0 and fids lt fid1,sscnt)   
      if sscnt eq 0 then retval='' else retval=retval(ss)
    endcase
   else:
endcase

chkcount=where(retval ne '',count)     ; return number of files

if loud and count eq 0 then message,/info,"No files found"

return,retval
end
